@@ -112,7 +112,7 @@ package Astro::Coord::ECI::TLE::Iridium;
 
 use base qw{Astro::Coord::ECI::TLE};
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use Astro::Coord::ECI::Sun;
 use Astro::Coord::ECI::Utils qw{:all};
@@ -433,6 +433,13 @@ a future release. The chances of it being fixed in a future release will
 be enhanced if someone claims to actually need it. This someone will be
 invited to help test the new code.
 
+B<NOTE also> that as of version 0.002_01 of this class, the 'backdate'
+attribute determines whether a set of orbital elements can be used for
+computations of flares before the epoch of the elements. If 'backdate'
+is false and the start time passed to flare() is earlier than the epoch,
+the start time is silently moved forward to the epoch -- or not so
+silently if this places the start time after the end time.
+
 =cut
 
 use constant DTFMT => '%d-%b-%Y %H:%M:%S (GMT)';
@@ -459,7 +466,16 @@ Error - The station must be a subclass of Astro::Coord::ECI.
 eod
 }
 my $start = shift || time ();
+unless ($self->get ('backdate')) {
+    my $real = $self->isa ('Astro::Coord::ECI::TLE::Set') ?
+	$self->select ($start) : $self;
+    my $epoch = $real->get ('epoch');
+    $start = $epoch if $start < $epoch;
+}
 my $end = shift || $start + 86400;
+$end >= $start or croak <<eod;
+Error - End time must be after start time.
+eod
 
 my @flares;
 my $illum = $self->get ('illum');
@@ -1564,6 +1580,8 @@ Thomas R. Wyant, III (F<wyant at cpan dot org>)
 Copyright 2006, 2007 by Thomas R. Wyant, III
 (F<wyant at cpan dot org>). All rights reserved.
 
+=head1 LICENSE
+
 This module is free software; you can use it, redistribute it and/or
 modify it under the same terms as Perl itself. Please see
 L<http://perldoc.perl.org/index-licence.html> for the current licenses.
